Class: Google::Apis::AlertcenterV1beta1::ActionInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::ActionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Metadata related to the action.
Instance Attribute Summary collapse
-
#evidence_locker_file_path ⇒ String
Google Cloud Storage location of the content that violated the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActionInfo
constructor
A new instance of ActionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActionInfo
Returns a new instance of ActionInfo.
212 213 214 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evidence_locker_file_path ⇒ String
Google Cloud Storage location of the content that violated the rule. This
field has format: "/"
Corresponds to the JSON property evidenceLockerFilePath
210 211 212 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 210 def evidence_locker_file_path @evidence_locker_file_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
217 218 219 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 217 def update!(**args) @evidence_locker_file_path = args[:evidence_locker_file_path] if args.key?(:evidence_locker_file_path) end |