Class: Google::Apis::AlertcenterV1beta1::AppsOutage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

An outage incident reported for a Google Workspace service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppsOutage

Returns a new instance of AppsOutage.



662
663
664
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dashboard_uriString

Link to the outage event in Google Workspace Status Dashboard Corresponds to the JSON property dashboardUri

Returns:

  • (String)


629
630
631
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 629

def dashboard_uri
  @dashboard_uri
end

#incident_tracking_idString

Incident tracking ID. Corresponds to the JSON property incidentTrackingId

Returns:

  • (String)


634
635
636
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 634

def incident_tracking_id
  @incident_tracking_id
end

#merge_infoGoogle::Apis::AlertcenterV1beta1::MergeInfo

New alert tracking numbers. Corresponds to the JSON property mergeInfo



639
640
641
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 639

def merge_info
  @merge_info
end

#next_update_timeString

Timestamp by which the next update is expected to arrive. Corresponds to the JSON property nextUpdateTime

Returns:

  • (String)


644
645
646
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 644

def next_update_time
  @next_update_time
end

#productsArray<String>

List of products impacted by the outage. Corresponds to the JSON property products

Returns:

  • (Array<String>)


649
650
651
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 649

def products
  @products
end

#resolution_timeString

Timestamp when the outage is expected to be resolved, or has confirmed resolution. Provided only when known. Corresponds to the JSON property resolutionTime

Returns:

  • (String)


655
656
657
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 655

def resolution_time
  @resolution_time
end

#statusString

Current outage status. Corresponds to the JSON property status

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 660

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



667
668
669
670
671
672
673
674
675
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 667

def update!(**args)
  @dashboard_uri = args[:dashboard_uri] if args.key?(:dashboard_uri)
  @incident_tracking_id = args[:incident_tracking_id] if args.key?(:incident_tracking_id)
  @merge_info = args[:merge_info] if args.key?(:merge_info)
  @next_update_time = args[:next_update_time] if args.key?(:next_update_time)
  @products = args[:products] if args.key?(:products)
  @resolution_time = args[:resolution_time] if args.key?(:resolution_time)
  @status = args[:status] if args.key?(:status)
end