Class: Google::Apis::AlertcenterV1beta1::BadWhitelist

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Alert for setting the domain or IP that malicious email comes from as whitelisted domain or IP in Gmail advanced settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BadWhitelist

Returns a new instance of BadWhitelist.



723
724
725
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_idGoogle::Apis::AlertcenterV1beta1::DomainId

Domain ID of Gmail phishing alerts. Corresponds to the JSON property domainId



706
707
708
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 706

def domain_id
  @domain_id
end

#malicious_entityGoogle::Apis::AlertcenterV1beta1::MaliciousEntity

Entity whose actions triggered a Gmail phishing alert. Corresponds to the JSON property maliciousEntity



711
712
713
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 711

def malicious_entity
  @malicious_entity
end

#messagesArray<Google::Apis::AlertcenterV1beta1::GmailMessageInfo>

The list of messages contained by this alert. Corresponds to the JSON property messages



716
717
718
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 716

def messages
  @messages
end

#source_ipString

The source IP address of the malicious email, for example, 127.0.0.1. Corresponds to the JSON property sourceIp

Returns:

  • (String)


721
722
723
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 721

def source_ip
  @source_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



728
729
730
731
732
733
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 728

def update!(**args)
  @domain_id = args[:domain_id] if args.key?(:domain_id)
  @malicious_entity = args[:malicious_entity] if args.key?(:malicious_entity)
  @messages = args[:messages] if args.key?(:messages)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
end