Class: Google::Apis::AlertcenterV1beta1::Csv

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

A representation of a CSV file attachment, as a list of column headers and a list of data rows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Csv

Returns a new instance of Csv.



914
915
916
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_rowsArray<Google::Apis::AlertcenterV1beta1::CsvRow>

The list of data rows in a CSV file, as string arrays rather than as a single comma-separated string. Corresponds to the JSON property dataRows



907
908
909
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 907

def data_rows
  @data_rows
end

#headersArray<String>

The list of headers for data columns in a CSV file. Corresponds to the JSON property headers

Returns:

  • (Array<String>)


912
913
914
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 912

def headers
  @headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



919
920
921
922
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 919

def update!(**args)
  @data_rows = args[:data_rows] if args.key?(:data_rows)
  @headers = args[:headers] if args.key?(:headers)
end