Class: Google::Apis::AlertcenterV1beta1::DeviceManagementRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Alerts from Device Management Rules configured by Admin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceManagementRule

Returns a new instance of DeviceManagementRule.



1080
1081
1082
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_idString

Required. The device ID. Corresponds to the JSON property deviceId

Returns:

  • (String)


1033
1034
1035
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1033

def device_id
  @device_id
end

#device_modelString

The model of the device. Corresponds to the JSON property deviceModel

Returns:

  • (String)


1038
1039
1040
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1038

def device_model
  @device_model
end

#device_typeString

The type of the device. Corresponds to the JSON property deviceType

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1043

def device_type
  @device_type
end

#emailString

The email of the user this alert was created for. Corresponds to the JSON property email

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1048

def email
  @email
end

#idString

ID of the rule that triggered the alert Corresponds to the JSON property id

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1053

def id
  @id
end

#ios_vendor_idString

Required for iOS, empty for others. Corresponds to the JSON property iosVendorId

Returns:

  • (String)


1058
1059
1060
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1058

def ios_vendor_id
  @ios_vendor_id
end

#owner_idString

Obfuscated ID of the owner of the device Corresponds to the JSON property ownerId

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1063

def owner_id
  @owner_id
end

#resource_idString

The device resource ID. Corresponds to the JSON property resourceId

Returns:

  • (String)


1068
1069
1070
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1068

def resource_id
  @resource_id
end

#rule_actionString

Action taken as result of the rule Corresponds to the JSON property ruleAction

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1073

def rule_action
  @rule_action
end

#serial_numberString

The serial number of the device. Corresponds to the JSON property serialNumber

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1078

def serial_number
  @serial_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1085

def update!(**args)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_model = args[:device_model] if args.key?(:device_model)
  @device_type = args[:device_type] if args.key?(:device_type)
  @email = args[:email] if args.key?(:email)
  @id = args[:id] if args.key?(:id)
  @ios_vendor_id = args[:ios_vendor_id] if args.key?(:ios_vendor_id)
  @owner_id = args[:owner_id] if args.key?(:owner_id)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @rule_action = args[:rule_action] if args.key?(:rule_action)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
end