Class: Google::Apis::AlertcenterV1beta1::EntityList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

EntityList stores entities in a format that can be translated to a table in the Alert Center UI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EntityList

Returns a new instance of EntityList.



1273
1274
1275
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitiesArray<Google::Apis::AlertcenterV1beta1::Entity>

List of entities affected by the alert. Corresponds to the JSON property entities



1260
1261
1262
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1260

def entities
  @entities
end

#headersArray<String>

Headers of the values in entities. If no value is defined in Entity, this field should be empty. Corresponds to the JSON property headers

Returns:

  • (Array<String>)


1266
1267
1268
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1266

def headers
  @headers
end

#nameString

Name of the key detail used to display this entity list. Corresponds to the JSON property name

Returns:

  • (String)


1271
1272
1273
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1271

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1278
1279
1280
1281
1282
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1278

def update!(**args)
  @entities = args[:entities] if args.key?(:entities)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
end