Class: Google::Apis::AlertcenterV1beta1::ListAlertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Response message for an alert listing request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAlertsResponse

Returns a new instance of ListAlertsResponse.



1508
1509
1510
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alertsArray<Google::Apis::AlertcenterV1beta1::Alert>

The list of alerts. Corresponds to the JSON property alerts



1498
1499
1500
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1498

def alerts
  @alerts
end

#next_page_tokenString

The token for the next page. If not empty, indicates that there may be more alerts that match the listing request; this value can be used in a subsequent ListAlertsRequest to get alerts continuing from last result of the current list call. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1506
1507
1508
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1506

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1513
1514
1515
1516
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1513

def update!(**args)
  @alerts = args[:alerts] if args.key?(:alerts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end