Class: Google::Apis::AlertcenterV1beta1::MandatoryServiceAnnouncement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Alert Created by the MSA team for communications necessary for continued use of Google Workspace Products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MandatoryServiceAnnouncement

Returns a new instance of MandatoryServiceAnnouncement.



1639
1640
1641
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Detailed, freeform text describing the announcement Corresponds to the JSON property description

Returns:

  • (String)


1632
1633
1634
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1632

def description
  @description
end

#titleString

One line summary of the announcement Corresponds to the JSON property title

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1637

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1644
1645
1646
1647
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1644

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @title = args[:title] if args.key?(:title)
end