Class: Google::Apis::AlertcenterV1beta1::SensitiveAdminAction
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::SensitiveAdminAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Alert that is triggered when Sensitive Admin Action occur in customer account.
Instance Attribute Summary collapse
-
#actor_email ⇒ String
Email of person who performed the action Corresponds to the JSON property
actorEmail. -
#event_time ⇒ String
The time at which event occurred Corresponds to the JSON property
eventTime. -
#primary_admin_changed_event ⇒ Google::Apis::AlertcenterV1beta1::PrimaryAdminChangedEvent
Event occurred when primary admin changed in customer's account.
-
#sso_profile_created_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileCreatedEvent
Event occurred when SSO Profile created in customer's account.
-
#sso_profile_deleted_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileDeletedEvent
Event occurred when SSO Profile deleted in customer's account.
-
#sso_profile_updated_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileUpdatedEvent
Event occurred when SSO Profile updated in customer's account.
-
#super_admin_password_reset_event ⇒ Google::Apis::AlertcenterV1beta1::SuperAdminPasswordResetEvent
Event occurred when password was reset for super admin in customer's account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SensitiveAdminAction
constructor
A new instance of SensitiveAdminAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SensitiveAdminAction
Returns a new instance of SensitiveAdminAction.
2152 2153 2154 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor_email ⇒ String
Email of person who performed the action
Corresponds to the JSON property actorEmail
2115 2116 2117 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2115 def actor_email @actor_email end |
#event_time ⇒ String
The time at which event occurred
Corresponds to the JSON property eventTime
2120 2121 2122 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2120 def event_time @event_time end |
#primary_admin_changed_event ⇒ Google::Apis::AlertcenterV1beta1::PrimaryAdminChangedEvent
Event occurred when primary admin changed in customer's account. The event are
being received from insight forwarder
Corresponds to the JSON property primaryAdminChangedEvent
2126 2127 2128 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2126 def primary_admin_changed_event @primary_admin_changed_event end |
#sso_profile_created_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileCreatedEvent
Event occurred when SSO Profile created in customer's account. The event are
being received from insight forwarder
Corresponds to the JSON property ssoProfileCreatedEvent
2132 2133 2134 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2132 def sso_profile_created_event @sso_profile_created_event end |
#sso_profile_deleted_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileDeletedEvent
Event occurred when SSO Profile deleted in customer's account. The event are
being received from insight forwarder
Corresponds to the JSON property ssoProfileDeletedEvent
2138 2139 2140 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2138 def sso_profile_deleted_event @sso_profile_deleted_event end |
#sso_profile_updated_event ⇒ Google::Apis::AlertcenterV1beta1::SsoProfileUpdatedEvent
Event occurred when SSO Profile updated in customer's account. The event are
being received from insight forwarder
Corresponds to the JSON property ssoProfileUpdatedEvent
2144 2145 2146 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2144 def sso_profile_updated_event @sso_profile_updated_event end |
#super_admin_password_reset_event ⇒ Google::Apis::AlertcenterV1beta1::SuperAdminPasswordResetEvent
Event occurred when password was reset for super admin in customer's account.
The event are being received from insight forwarder
Corresponds to the JSON property superAdminPasswordResetEvent
2150 2151 2152 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2150 def super_admin_password_reset_event @super_admin_password_reset_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2157 2158 2159 2160 2161 2162 2163 2164 2165 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2157 def update!(**args) @actor_email = args[:actor_email] if args.key?(:actor_email) @event_time = args[:event_time] if args.key?(:event_time) @primary_admin_changed_event = args[:primary_admin_changed_event] if args.key?(:primary_admin_changed_event) @sso_profile_created_event = args[:sso_profile_created_event] if args.key?(:sso_profile_created_event) @sso_profile_deleted_event = args[:sso_profile_deleted_event] if args.key?(:sso_profile_deleted_event) @sso_profile_updated_event = args[:sso_profile_updated_event] if args.key?(:sso_profile_updated_event) @super_admin_password_reset_event = args[:super_admin_password_reset_event] if args.key?(:super_admin_password_reset_event) end |