Class: Google::Apis::AlertcenterV1beta1::SsoProfileUpdatedEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Event occurred when SSO Profile updated in customer's account. The event are being received from insight forwarder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SsoProfileUpdatedEvent

Returns a new instance of SsoProfileUpdatedEvent.



2103
2104
2105
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inbound_sso_profile_changesString

changes made to sso profile Corresponds to the JSON property inboundSsoProfileChanges

Returns:

  • (String)


2096
2097
2098
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2096

def inbound_sso_profile_changes
  @inbound_sso_profile_changes
end

#inbound_sso_profile_nameString

sso profile name which got updated Corresponds to the JSON property inboundSsoProfileName

Returns:

  • (String)


2101
2102
2103
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2101

def inbound_sso_profile_name
  @inbound_sso_profile_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2108
2109
2110
2111
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2108

def update!(**args)
  @inbound_sso_profile_changes = args[:inbound_sso_profile_changes] if args.key?(:inbound_sso_profile_changes)
  @inbound_sso_profile_name = args[:inbound_sso_profile_name] if args.key?(:inbound_sso_profile_name)
end