Class: Google::Apis::AlertcenterV1beta1::SuperAdminPasswordResetEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Event occurred when password was reset for super admin in customer's account. The event are being received from insight forwarder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperAdminPasswordResetEvent

Returns a new instance of SuperAdminPasswordResetEvent.



2261
2262
2263
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_emailString

email of person whose password was reset Corresponds to the JSON property userEmail

Returns:

  • (String)


2259
2260
2261
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2259

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2266
2267
2268
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2266

def update!(**args)
  @user_email = args[:user_email] if args.key?(:user_email)
end