Class: Google::Apis::AlertcenterV1beta1::TransferError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Details for an invalid transfer or forward.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferError

Returns a new instance of TransferError.



2413
2414
2415
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

User's email address. This may be unavailable if the entity was deleted. Corresponds to the JSON property email

Returns:

  • (String)


2389
2390
2391
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2389

def email
  @email
end

#entity_typeString

Type of entity being transferred to. For ring group members, this should always be USER. Corresponds to the JSON property entityType

Returns:

  • (String)


2395
2396
2397
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2395

def entity_type
  @entity_type
end

#idString

Ring group or auto attendant ID. Not set for users. Corresponds to the JSON property id

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2400

def id
  @id
end

#invalid_reasonString

Reason for the error. Corresponds to the JSON property invalidReason

Returns:

  • (String)


2405
2406
2407
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2405

def invalid_reason
  @invalid_reason
end

#nameString

User's full name, or the ring group / auto attendant name. This may be unavailable if the entity was deleted. Corresponds to the JSON property name

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2411

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2418
2419
2420
2421
2422
2423
2424
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2418

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @id = args[:id] if args.key?(:id)
  @invalid_reason = args[:invalid_reason] if args.key?(:invalid_reason)
  @name = args[:name] if args.key?(:name)
end