Class: Google::Apis::AlertcenterV1beta1::UndeleteAlertRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::UndeleteAlertRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
A request to undelete a specific alert that was marked for deletion.
Instance Attribute Summary collapse
-
#customer_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UndeleteAlertRequest
constructor
A new instance of UndeleteAlertRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UndeleteAlertRequest
Returns a new instance of UndeleteAlertRequest.
2459 2460 2461 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_id ⇒ String
Optional. The unique identifier of the Google Workspace account of the
customer the alert is associated with. The customer_id must have the initial
"C" stripped (for example, 046psxkn). Inferred from the caller identity if
not provided. Find your customer ID.
Corresponds to the JSON property customerId
2457 2458 2459 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2457 def customer_id @customer_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2464 2465 2466 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2464 def update!(**args) @customer_id = args[:customer_id] if args.key?(:customer_id) end |