Class: Google::Apis::AlertcenterV1beta1::VoiceMisconfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

An alert triggered when Google Voice configuration becomes invalid, generally due to an external entity being modified or deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoiceMisconfiguration

Returns a new instance of VoiceMisconfiguration.



2628
2629
2630
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_nameString

Name of the entity whose configuration is now invalid. Corresponds to the JSON property entityName

Returns:

  • (String)


2601
2602
2603
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2601

def entity_name
  @entity_name
end

#entity_typeString

Type of the entity whose configuration is now invalid. Corresponds to the JSON property entityType

Returns:

  • (String)


2606
2607
2608
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2606

def entity_type
  @entity_type
end

#fix_uriString

Link that the admin can follow to fix the issue. Corresponds to the JSON property fixUri

Returns:

  • (String)


2611
2612
2613
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2611

def fix_uri
  @fix_uri
end

#members_misconfigurationGoogle::Apis::AlertcenterV1beta1::TransferMisconfiguration

Error related to transferring or forwarding a phone call. Corresponds to the JSON property membersMisconfiguration



2616
2617
2618
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2616

def members_misconfiguration
  @members_misconfiguration
end

#transfer_misconfigurationGoogle::Apis::AlertcenterV1beta1::TransferMisconfiguration

Error related to transferring or forwarding a phone call. Corresponds to the JSON property transferMisconfiguration



2621
2622
2623
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2621

def transfer_misconfiguration
  @transfer_misconfiguration
end

#voicemail_misconfigurationGoogle::Apis::AlertcenterV1beta1::VoicemailMisconfiguration

Issue(s) with sending to voicemail. Corresponds to the JSON property voicemailMisconfiguration



2626
2627
2628
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2626

def voicemail_misconfiguration
  @voicemail_misconfiguration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2633
2634
2635
2636
2637
2638
2639
2640
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2633

def update!(**args)
  @entity_name = args[:entity_name] if args.key?(:entity_name)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @fix_uri = args[:fix_uri] if args.key?(:fix_uri)
  @members_misconfiguration = args[:members_misconfiguration] if args.key?(:members_misconfiguration)
  @transfer_misconfiguration = args[:transfer_misconfiguration] if args.key?(:transfer_misconfiguration)
  @voicemail_misconfiguration = args[:voicemail_misconfiguration] if args.key?(:voicemail_misconfiguration)
end