Class: Google::Apis::AlertcenterV1beta1::ActivityRule
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::ActivityRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Alerts from Google Workspace Security Center rules service configured by an admin.
Instance Attribute Summary collapse
-
#action_names ⇒ Array<String>
List of action names associated with the rule threshold.
-
#create_time ⇒ String
Rule create timestamp.
-
#description ⇒ String
Description of the rule.
-
#display_name ⇒ String
Alert display name.
-
#name ⇒ String
Rule name.
-
#query ⇒ String
Query that is used to get the data from the associated source.
-
#superseded_alerts ⇒ Array<String>
List of alert IDs superseded by this alert.
-
#superseding_alert ⇒ String
Alert ID superseding this alert.
-
#threshold ⇒ String
Alert threshold is for example “COUNT > 5”.
-
#trigger_source ⇒ String
The trigger sources for this rule.
-
#update_time ⇒ String
The timestamp of the last update to the rule.
-
#window_size ⇒ String
Rule window size.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityRule
constructor
A new instance of ActivityRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityRule
Returns a new instance of ActivityRule.
292 293 294 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_names ⇒ Array<String>
List of action names associated with the rule threshold.
Corresponds to the JSON property actionNames
230 231 232 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 230 def action_names @action_names end |
#create_time ⇒ String
Rule create timestamp.
Corresponds to the JSON property createTime
235 236 237 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 235 def create_time @create_time end |
#description ⇒ String
Description of the rule.
Corresponds to the JSON property description
240 241 242 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 240 def description @description end |
#display_name ⇒ String
Alert display name.
Corresponds to the JSON property displayName
245 246 247 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 245 def display_name @display_name end |
#name ⇒ String
Rule name.
Corresponds to the JSON property name
250 251 252 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 250 def name @name end |
#query ⇒ String
Query that is used to get the data from the associated source.
Corresponds to the JSON property query
255 256 257 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 255 def query @query end |
#superseded_alerts ⇒ Array<String>
List of alert IDs superseded by this alert. It is used to indicate that this
alert is essentially extension of superseded alerts and we found the
relationship after creating these alerts.
Corresponds to the JSON property supersededAlerts
262 263 264 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 262 def superseded_alerts @superseded_alerts end |
#superseding_alert ⇒ String
Alert ID superseding this alert. It is used to indicate that superseding alert
is essentially extension of this alert and we found the relationship after
creating both alerts.
Corresponds to the JSON property supersedingAlert
269 270 271 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 269 def superseding_alert @superseding_alert end |
#threshold ⇒ String
Alert threshold is for example “COUNT > 5”.
Corresponds to the JSON property threshold
274 275 276 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 274 def threshold @threshold end |
#trigger_source ⇒ String
The trigger sources for this rule. * GMAIL_EVENTS * DEVICE_EVENTS *
USER_EVENTS
Corresponds to the JSON property triggerSource
280 281 282 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 280 def trigger_source @trigger_source end |
#update_time ⇒ String
The timestamp of the last update to the rule.
Corresponds to the JSON property updateTime
285 286 287 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 285 def update_time @update_time end |
#window_size ⇒ String
Rule window size. Possible values are 1 hour or 24 hours.
Corresponds to the JSON property windowSize
290 291 292 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 290 def window_size @window_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 297 def update!(**args) @action_names = args[:action_names] if args.key?(:action_names) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @query = args[:query] if args.key?(:query) @superseded_alerts = args[:superseded_alerts] if args.key?(:superseded_alerts) @superseding_alert = args[:superseding_alert] if args.key?(:superseding_alert) @threshold = args[:threshold] if args.key?(:threshold) @trigger_source = args[:trigger_source] if args.key?(:trigger_source) @update_time = args[:update_time] if args.key?(:update_time) @window_size = args[:window_size] if args.key?(:window_size) end |