Class: Google::Apis::AlertcenterV1beta1::Alert
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::Alert
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
An alert affecting a customer.
Instance Attribute Summary collapse
-
#alert_id ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#customer_id ⇒ String
Output only.
-
#data ⇒ Hash<String,Object>
Optional.
-
#deleted ⇒ Boolean
(also: #deleted?)
Output only.
-
#end_time ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::AlertcenterV1beta1::AlertMetadata
An alert metadata.
-
#security_investigation_tool_link ⇒ String
Output only.
-
#source ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Alert
constructor
A new instance of Alert.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Alert
Returns a new instance of Alert.
402 403 404 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_id ⇒ String
Output only. The unique identifier for the alert.
Corresponds to the JSON property alertId
320 321 322 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 320 def alert_id @alert_id end |
#create_time ⇒ String
Output only. The time this alert was created.
Corresponds to the JSON property createTime
325 326 327 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 325 def create_time @create_time end |
#customer_id ⇒ String
Output only. The unique identifier of the Google Workspace account of the
customer.
Corresponds to the JSON property customerId
331 332 333 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 331 def customer_id @customer_id end |
#data ⇒ Hash<String,Object>
Optional. The data associated with this alert, for example google.apps.
alertcenter.type.DeviceCompromised.
Corresponds to the JSON property data
337 338 339 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 337 def data @data end |
#deleted ⇒ Boolean Also known as: deleted?
Output only. True if this alert is marked for deletion.
Corresponds to the JSON property deleted
342 343 344 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 342 def deleted @deleted end |
#end_time ⇒ String
Optional. The time the event that caused this alert ceased being active. If
provided, the end time must not be earlier than the start time. If not
provided, it indicates an ongoing alert.
Corresponds to the JSON property endTime
350 351 352 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 350 def end_time @end_time end |
#etag ⇒ String
Optional. etag is used for optimistic concurrency control as a way to help
prevent simultaneous updates of an alert from overwriting each other. It is
strongly suggested that systems make use of the etag in the read-modify-
write cycle to perform alert updates in order to avoid race conditions: An
etag is returned in the response which contains alerts, and systems are
expected to put that etag in the request to update alert to ensure that their
change will be applied to the same version of the alert. If no etag is
provided in the call to update alert, then the existing alert is overwritten
blindly.
Corresponds to the JSON property etag
363 364 365 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 363 def etag @etag end |
#metadata ⇒ Google::Apis::AlertcenterV1beta1::AlertMetadata
An alert metadata.
Corresponds to the JSON property metadata
368 369 370 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 368 def @metadata end |
#security_investigation_tool_link ⇒ String
Output only. An optional Security Investigation Tool query for this alert.
Corresponds to the JSON property securityInvestigationToolLink
374 375 376 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 374 def security_investigation_tool_link @security_investigation_tool_link end |
#source ⇒ String
Required. A unique identifier for the system that reported the alert. This is output only after alert is created. Supported sources are any of the following:
- Google Operations * Mobile device management * Gmail phishing * Data Loss
Prevention * Domain wide takeout * State sponsored attack * Google identity *
Apps outage
Corresponds to the JSON property
source
383 384 385 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 383 def source @source end |
#start_time ⇒ String
Required. The time the event that caused this alert was started or detected.
Corresponds to the JSON property startTime
388 389 390 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 388 def start_time @start_time end |
#type ⇒ String
Required. The type of the alert. This is output only after alert is created.
For a list of available alert types see Google Workspace Alert types.
Corresponds to the JSON property type
395 396 397 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 395 def type @type end |
#update_time ⇒ String
Output only. The time this alert was last updated.
Corresponds to the JSON property updateTime
400 401 402 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 400 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 407 def update!(**args) @alert_id = args[:alert_id] if args.key?(:alert_id) @create_time = args[:create_time] if args.key?(:create_time) @customer_id = args[:customer_id] if args.key?(:customer_id) @data = args[:data] if args.key?(:data) @deleted = args[:deleted] if args.key?(:deleted) @end_time = args[:end_time] if args.key?(:end_time) @etag = args[:etag] if args.key?(:etag) @metadata = args[:metadata] if args.key?(:metadata) @security_investigation_tool_link = args[:security_investigation_tool_link] if args.key?(:security_investigation_tool_link) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |