Class: Google::Apis::AlertcenterV1beta1::AlertMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::AlertMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
An alert metadata.
Instance Attribute Summary collapse
-
#alert_id ⇒ String
Output only.
-
#assignee ⇒ String
The email address of the user assigned to the alert.
-
#customer_id ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#severity ⇒ String
The severity value of the alert.
-
#status ⇒ String
The current status of the alert.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlertMetadata
constructor
A new instance of AlertMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlertMetadata
Returns a new instance of AlertMetadata.
526 527 528 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_id ⇒ String
Output only. The alert identifier.
Corresponds to the JSON property alertId
481 482 483 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 481 def alert_id @alert_id end |
#assignee ⇒ String
The email address of the user assigned to the alert.
Corresponds to the JSON property assignee
486 487 488 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 486 def assignee @assignee end |
#customer_id ⇒ String
Output only. The unique identifier of the Google Workspace account of the
customer.
Corresponds to the JSON property customerId
492 493 494 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 492 def customer_id @customer_id end |
#etag ⇒ String
Optional. etag is used for optimistic concurrency control as a way to help
prevent simultaneous updates of an alert metadata from overwriting each other.
It is strongly suggested that systems make use of the etag in the read-
modify-write cycle to perform metadata updates in order to avoid race
conditions: An etag is returned in the response which contains alert
metadata, and systems are expected to put that etag in the request to update
alert metadata to ensure that their change will be applied to the same version
of the alert metadata. If no etag is provided in the call to update alert
metadata, then the existing alert metadata is overwritten blindly.
Corresponds to the JSON property etag
505 506 507 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 505 def etag @etag end |
#severity ⇒ String
The severity value of the alert. Alert Center will set this field at alert
creation time, default's to an empty string when it could not be determined.
The supported values for update actions on this field are the following: *
HIGH * MEDIUM * LOW
Corresponds to the JSON property severity
513 514 515 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 513 def severity @severity end |
#status ⇒ String
The current status of the alert. The supported values are the following: *
NOT_STARTED * IN_PROGRESS * CLOSED
Corresponds to the JSON property status
519 520 521 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 519 def status @status end |
#update_time ⇒ String
Output only. The time this metadata was last updated.
Corresponds to the JSON property updateTime
524 525 526 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 524 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
531 532 533 534 535 536 537 538 539 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 531 def update!(**args) @alert_id = args[:alert_id] if args.key?(:alert_id) @assignee = args[:assignee] if args.key?(:assignee) @customer_id = args[:customer_id] if args.key?(:customer_id) @etag = args[:etag] if args.key?(:etag) @severity = args[:severity] if args.key?(:severity) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |