Class: Google::Apis::AlertcenterV1beta1::DriveSyncStateChanged
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::DriveSyncStateChanged
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Alerts for when a user is restricted from syncing content from clients such as Drive for Desktop.
Instance Attribute Summary collapse
-
#email ⇒ String
Email of the user affected.
-
#sync_pause_start_time ⇒ String
Time at which sync was paused.
-
#sync_state ⇒ String
The current sync state.
-
#sync_state_change_reason ⇒ String
The reason for the sync state change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DriveSyncStateChanged
constructor
A new instance of DriveSyncStateChanged.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DriveSyncStateChanged
Returns a new instance of DriveSyncStateChanged.
1189 1190 1191 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Email of the user affected.
Corresponds to the JSON property email
1172 1173 1174 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1172 def email @email end |
#sync_pause_start_time ⇒ String
Time at which sync was paused.
Corresponds to the JSON property syncPauseStartTime
1177 1178 1179 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1177 def sync_pause_start_time @sync_pause_start_time end |
#sync_state ⇒ String
The current sync state.
Corresponds to the JSON property syncState
1182 1183 1184 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1182 def sync_state @sync_state end |
#sync_state_change_reason ⇒ String
The reason for the sync state change.
Corresponds to the JSON property syncStateChangeReason
1187 1188 1189 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1187 def sync_state_change_reason @sync_state_change_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1194 1195 1196 1197 1198 1199 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1194 def update!(**args) @email = args[:email] if args.key?(:email) @sync_pause_start_time = args[:sync_pause_start_time] if args.key?(:sync_pause_start_time) @sync_state = args[:sync_state] if args.key?(:sync_state) @sync_state_change_reason = args[:sync_state_change_reason] if args.key?(:sync_state_change_reason) end |