Class: Google::Apis::AlertcenterV1beta1::Entity
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::Entity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Individual entity affected by, or related to, an alert.
Instance Attribute Summary collapse
-
#link ⇒ String
Link to a Security Investigation Tool search based on this entity, if available.
-
#name ⇒ String
Human-readable name of this entity, such as an email address, file ID, or device name.
-
#values ⇒ Array<String>
Extra values beyond name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Entity
constructor
A new instance of Entity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Entity
Returns a new instance of Entity.
1240 1241 1242 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#link ⇒ String
Link to a Security Investigation Tool search based on this entity, if
available.
Corresponds to the JSON property link
1226 1227 1228 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1226 def link @link end |
#name ⇒ String
Human-readable name of this entity, such as an email address, file ID, or
device name.
Corresponds to the JSON property name
1232 1233 1234 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1232 def name @name end |
#values ⇒ Array<String>
Extra values beyond name. The order of values should align with headers in
EntityList.
Corresponds to the JSON property values
1238 1239 1240 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1238 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1245 1246 1247 1248 1249 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1245 def update!(**args) @link = args[:link] if args.key?(:link) @name = args[:name] if args.key?(:name) @values = args[:values] if args.key?(:values) end |