Class: Google::Apis::AlertcenterV1beta1::GoogleOperations
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::GoogleOperations
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
An incident reported by Google Operations for a Google Workspace application.
Instance Attribute Summary collapse
-
#affected_user_emails ⇒ Array<String>
The list of emails which correspond to the users directly affected by the incident.
-
#attachment_data ⇒ Google::Apis::AlertcenterV1beta1::Attachment
Attachment with application-specific information about an alert.
-
#description ⇒ String
A detailed, freeform incident description.
-
#domain ⇒ String
Customer domain for email template personalization.
-
#header ⇒ String
A header to display above the incident message.
-
#title ⇒ String
A one-line incident description.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleOperations
constructor
A new instance of GoogleOperations.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleOperations
Returns a new instance of GoogleOperations.
1388 1389 1390 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_user_emails ⇒ Array<String>
The list of emails which correspond to the users directly affected by the
incident.
Corresponds to the JSON property affectedUserEmails
1360 1361 1362 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1360 def affected_user_emails @affected_user_emails end |
#attachment_data ⇒ Google::Apis::AlertcenterV1beta1::Attachment
Attachment with application-specific information about an alert.
Corresponds to the JSON property attachmentData
1365 1366 1367 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1365 def @attachment_data end |
#description ⇒ String
A detailed, freeform incident description.
Corresponds to the JSON property description
1370 1371 1372 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1370 def description @description end |
#domain ⇒ String
Customer domain for email template personalization.
Corresponds to the JSON property domain
1375 1376 1377 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1375 def domain @domain end |
#header ⇒ String
A header to display above the incident message. Typically used to attach a
localized notice on the timeline for followup comms translations.
Corresponds to the JSON property header
1381 1382 1383 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1381 def header @header end |
#title ⇒ String
A one-line incident description.
Corresponds to the JSON property title
1386 1387 1388 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1386 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1393 1394 1395 1396 1397 1398 1399 1400 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1393 def update!(**args) @affected_user_emails = args[:affected_user_emails] if args.key?(:affected_user_emails) @attachment_data = args[:attachment_data] if args.key?(:attachment_data) @description = args[:description] if args.key?(:description) @domain = args[:domain] if args.key?(:domain) @header = args[:header] if args.key?(:header) @title = args[:title] if args.key?(:title) end |