Class: Google::Apis::AlertcenterV1beta1::PrimaryAdminChangedEvent
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::PrimaryAdminChangedEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Event occurred when primary admin changed in customer's account. The event are being received from insight forwarder
Instance Attribute Summary collapse
-
#domain ⇒ String
domain in which actioned occurred Corresponds to the JSON property
domain. -
#previous_admin_email ⇒ String
Email of person who was the primary admin before the action Corresponds to the JSON property
previousAdminEmail. -
#updated_admin_email ⇒ String
Email of person who is the primary admin after the action Corresponds to the JSON property
updatedAdminEmail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrimaryAdminChangedEvent
constructor
A new instance of PrimaryAdminChangedEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrimaryAdminChangedEvent
Returns a new instance of PrimaryAdminChangedEvent.
1803 1804 1805 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
domain in which actioned occurred
Corresponds to the JSON property domain
1791 1792 1793 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1791 def domain @domain end |
#previous_admin_email ⇒ String
Email of person who was the primary admin before the action
Corresponds to the JSON property previousAdminEmail
1796 1797 1798 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1796 def previous_admin_email @previous_admin_email end |
#updated_admin_email ⇒ String
Email of person who is the primary admin after the action
Corresponds to the JSON property updatedAdminEmail
1801 1802 1803 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1801 def updated_admin_email @updated_admin_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1808 1809 1810 1811 1812 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1808 def update!(**args) @domain = args[:domain] if args.key?(:domain) @previous_admin_email = args[:previous_admin_email] if args.key?(:previous_admin_email) @updated_admin_email = args[:updated_admin_email] if args.key?(:updated_admin_email) end |