Class: Google::Apis::AlertcenterV1beta1::ResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlertcenterV1beta1::ResourceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb
Overview
Proto that contains resource information.
Instance Attribute Summary collapse
-
#chat_attachment_id ⇒ String
Chat attachment ID.
-
#chat_message_id ⇒ String
Chat message ID.
-
#device_id ⇒ String
Id to identify a device.
-
#document_id ⇒ String
Drive file ID.
-
#message_id ⇒ String
RFC2822 message ID.
-
#resource_title ⇒ String
Title of the resource, for example email subject, or document title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceInfo
constructor
A new instance of ResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceInfo
Returns a new instance of ResourceInfo.
1917 1918 1919 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chat_attachment_id ⇒ String
Chat attachment ID.
Corresponds to the JSON property chatAttachmentId
1889 1890 1891 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1889 def @chat_attachment_id end |
#chat_message_id ⇒ String
Chat message ID.
Corresponds to the JSON property chatMessageId
1894 1895 1896 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1894 def @chat_message_id end |
#device_id ⇒ String
Id to identify a device. For example, for Android devices, this is the "
Android Device Id" and for Chrome OS devices, it's the "Device Virtual Id".
Corresponds to the JSON property deviceId
1900 1901 1902 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1900 def device_id @device_id end |
#document_id ⇒ String
Drive file ID.
Corresponds to the JSON property documentId
1905 1906 1907 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1905 def document_id @document_id end |
#message_id ⇒ String
RFC2822 message ID.
Corresponds to the JSON property messageId
1910 1911 1912 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1910 def @message_id end |
#resource_title ⇒ String
Title of the resource, for example email subject, or document title.
Corresponds to the JSON property resourceTitle
1915 1916 1917 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1915 def resource_title @resource_title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1922 1923 1924 1925 1926 1927 1928 1929 |
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1922 def update!(**args) @chat_attachment_id = args[:chat_attachment_id] if args.key?(:chat_attachment_id) @chat_message_id = args[:chat_message_id] if args.key?(:chat_message_id) @device_id = args[:device_id] if args.key?(:device_id) @document_id = args[:document_id] if args.key?(:document_id) @message_id = args[:message_id] if args.key?(:message_id) @resource_title = args[:resource_title] if args.key?(:resource_title) end |