Class: Google::Apis::AlertcenterV1beta1::RuleViolationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Common alert information about violated rules that are configured by Google Workspace administrators.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuleViolationInfo

Returns a new instance of RuleViolationInfo.



2022
2023
2024
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_sourceString

Source of the data. Corresponds to the JSON property dataSource

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1965

def data_source
  @data_source
end

#event_typeString

Event associated with this alert after applying the rule. Corresponds to the JSON property eventType

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1970

def event_type
  @event_type
end

#match_infoArray<Google::Apis::AlertcenterV1beta1::MatchInfo>

List of matches that were found in the resource content. Corresponds to the JSON property matchInfo



1975
1976
1977
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1975

def match_info
  @match_info
end

#recipientsArray<String>

Resource recipients. For Drive, they are grantees that the Drive file was shared with at the time of rule triggering. Valid values include user emails, group emails, domains, or 'anyone' if the file was publicly accessible. If the file was private the recipients list will be empty. For Gmail, they are emails of the users or groups that the Gmail message was sent to. Corresponds to the JSON property recipients

Returns:

  • (Array<String>)


1984
1985
1986
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1984

def recipients
  @recipients
end

#resource_infoGoogle::Apis::AlertcenterV1beta1::ResourceInfo

Proto that contains resource information. Corresponds to the JSON property resourceInfo



1989
1990
1991
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1989

def resource_info
  @resource_info
end

#rule_infoGoogle::Apis::AlertcenterV1beta1::RuleInfo

Proto that contains rule information. Corresponds to the JSON property ruleInfo



1994
1995
1996
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1994

def rule_info
  @rule_info
end

#suppressed_action_typesArray<String>

Actions suppressed due to other actions with higher priority. Corresponds to the JSON property suppressedActionTypes

Returns:

  • (Array<String>)


1999
2000
2001
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 1999

def suppressed_action_types
  @suppressed_action_types
end

#triggerString

Trigger of the rule. Corresponds to the JSON property trigger

Returns:

  • (String)


2004
2005
2006
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2004

def trigger
  @trigger
end

#triggered_action_infoArray<Google::Apis::AlertcenterV1beta1::ActionInfo>

Metadata related to the triggered actions. Corresponds to the JSON property triggeredActionInfo



2009
2010
2011
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2009

def triggered_action_info
  @triggered_action_info
end

#triggered_action_typesArray<String>

Actions applied as a consequence of the rule being triggered. Corresponds to the JSON property triggeredActionTypes

Returns:

  • (Array<String>)


2014
2015
2016
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2014

def triggered_action_types
  @triggered_action_types
end

#triggering_user_emailString

Email of the user who caused the violation. Value could be empty if not applicable, for example, a violation found by drive continuous scan. Corresponds to the JSON property triggeringUserEmail

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2020

def triggering_user_email
  @triggering_user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2027

def update!(**args)
  @data_source = args[:data_source] if args.key?(:data_source)
  @event_type = args[:event_type] if args.key?(:event_type)
  @match_info = args[:match_info] if args.key?(:match_info)
  @recipients = args[:recipients] if args.key?(:recipients)
  @resource_info = args[:resource_info] if args.key?(:resource_info)
  @rule_info = args[:rule_info] if args.key?(:rule_info)
  @suppressed_action_types = args[:suppressed_action_types] if args.key?(:suppressed_action_types)
  @trigger = args[:trigger] if args.key?(:trigger)
  @triggered_action_info = args[:triggered_action_info] if args.key?(:triggered_action_info)
  @triggered_action_types = args[:triggered_action_types] if args.key?(:triggered_action_types)
  @triggering_user_email = args[:triggering_user_email] if args.key?(:triggering_user_email)
end