Class: Google::Apis::AlertcenterV1beta1::SuspiciousActivitySecurityDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Detailed information of a single MDM suspicious activity event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuspiciousActivitySecurityDetail

Returns a new instance of SuspiciousActivitySecurityDetail.



2364
2365
2366
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_idString

Required. The device ID. Corresponds to the JSON property deviceId

Returns:

  • (String)


2322
2323
2324
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2322

def device_id
  @device_id
end

#device_modelString

The model of the device. Corresponds to the JSON property deviceModel

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2327

def device_model
  @device_model
end

#device_propertyString

The device property which was changed. Corresponds to the JSON property deviceProperty

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2332

def device_property
  @device_property
end

#device_typeString

The type of the device. Corresponds to the JSON property deviceType

Returns:

  • (String)


2337
2338
2339
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2337

def device_type
  @device_type
end

#ios_vendor_idString

Required for iOS, empty for others. Corresponds to the JSON property iosVendorId

Returns:

  • (String)


2342
2343
2344
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2342

def ios_vendor_id
  @ios_vendor_id
end

#new_valueString

The new value of the device property after the change. Corresponds to the JSON property newValue

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2347

def new_value
  @new_value
end

#old_valueString

The old value of the device property before the change. Corresponds to the JSON property oldValue

Returns:

  • (String)


2352
2353
2354
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2352

def old_value
  @old_value
end

#resource_idString

The device resource ID. Corresponds to the JSON property resourceId

Returns:

  • (String)


2357
2358
2359
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2357

def resource_id
  @resource_id
end

#serial_numberString

The serial number of the device. Corresponds to the JSON property serialNumber

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2362

def serial_number
  @serial_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2369

def update!(**args)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_model = args[:device_model] if args.key?(:device_model)
  @device_property = args[:device_property] if args.key?(:device_property)
  @device_type = args[:device_type] if args.key?(:device_type)
  @ios_vendor_id = args[:ios_vendor_id] if args.key?(:ios_vendor_id)
  @new_value = args[:new_value] if args.key?(:new_value)
  @old_value = args[:old_value] if args.key?(:old_value)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
end