Class: Google::Apis::AlertcenterV1beta1::VaultAcceleratedDeletion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alertcenter_v1beta1/classes.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb,
lib/google/apis/alertcenter_v1beta1/representations.rb

Overview

Alert that is triggered when a Vault accelerated deletion request is created or canceled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VaultAcceleratedDeletion

Returns a new instance of VaultAcceleratedDeletion.



2573
2574
2575
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_typeString

The action can be one of create and cancel Corresponds to the JSON property actionType

Returns:

  • (String)


2549
2550
2551
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2549

def action_type
  @action_type
end

#app_typeString

Currentlty only Gmail is supported as app type Corresponds to the JSON property appType

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2554

def app_type
  @app_type
end

#create_timeString

The UTC timestamp of when the AD request was created Corresponds to the JSON property createTime

Returns:

  • (String)


2559
2560
2561
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2559

def create_time
  @create_time
end

#deletion_request_idString

Accelerated deletion request ID intended to be used to construct the Vault UI link to the AD request Corresponds to the JSON property deletionRequestId

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2565

def deletion_request_id
  @deletion_request_id
end

#matter_idString

Matter ID of the accelerated deletion request intended to be used to construct the Vault UI link to the AD request Corresponds to the JSON property matterId

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2571

def matter_id
  @matter_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2578
2579
2580
2581
2582
2583
2584
# File 'lib/google/apis/alertcenter_v1beta1/classes.rb', line 2578

def update!(**args)
  @action_type = args[:action_type] if args.key?(:action_type)
  @app_type = args[:app_type] if args.key?(:app_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deletion_request_id = args[:deletion_request_id] if args.key?(:deletion_request_id)
  @matter_id = args[:matter_id] if args.key?(:matter_id)
end